@@ -2,3 +2,5 @@ from .pyplot import interactive_hist as hist
 from .pyplot import interactive_plot as plot
 from .pyplot import interactive_imshow as imshow
 from .pyplot import interactive_scatter as scatter
+from .pyplot import interactive_axhline as axhline
+from .pyplot import interactive_axvline as axvline
